@@ -1,7 +1,9 @@
 import os
-from .utils import scanner,dynamicImport,typeNameConvert
+
+from .callWithTypeCheck import callWithTypeCheck
+from .utils import dynamicImport
 from .settings import ALIVE_SYMBOL
-from .typeConverter import convertParameters
+from .scanner import scanner
 
 infoCache = {}
 moduleCache = {}
@@ -24,8 +26,8 @@ async def funcRegister(request):
         funcName, input, output = scanner(source.read())
         funcCache[funcName] = getattr(module,funcName)
         infoCache[funcName] = {
-            "input":list(map(typeNameConvert,input)),
-            "output": list(map(typeNameConvert,output))
+            "input": input,
+            "output": output
         }
     return funcName
 
@@ -33,11 +35,13 @@ async def funcRegister(request):
 async def callFunc(request):
     data=await request.json()
     funcName = request.match_info.get('funcName', "Anonymous")
-    res=funcCache[funcName](*convertParameters(infoCache[funcName]["input"],data["args"]))
-    return convertParameters(infoCache[funcName]["output"],res)
+    return callWithTypeCheck(funcCache[funcName],
+                             infoCache[funcName]["input"],
+                             infoCache[funcName]["output"],
+                             data["args"])
 
 
-def getFuncInfo(request):
+async def getFuncInfo(request):
     name = request.match_info.get('funcName')
     try:
         return infoCache[name]
